@@ -364,6 +364,33 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                 add_acls.append(na)
                 n_index += 1
 
+        # Check any ACLs we found to add against existing ACLs, ignoring the
+        # SG rule ID key. This eliminates any false-positives where the
+        # normalized cidr for two SG rules is the same value, since there
+        # will only be a single ACL that matches exactly with the SG rule ID.
+        if add_acls:
+            def copy_acl_rem_id_key(acl):
+                acl_copy = acl.copy()
+                del acl_copy[ovn_const.OVN_SG_RULE_EXT_ID_KEY]
+                return acl_copy
+
+            add_rem_acls = []
+            # Make a list of non-default rule ACLs (they have a security group
+            # rule id). See ovn_default_acls code/comment above for more info.
+            nd_ovn_acls = [copy_acl_rem_id_key(oa) for oa in ovn_acls
+                           if ovn_const.OVN_SG_RULE_EXT_ID_KEY in oa]
+            # We must copy here since we need to keep the original
+            # 'add_acl' intact for removal
+            for add_acl in add_acls:
+                add_acl_copy = copy_acl_rem_id_key(add_acl)
+                if add_acl_copy in nd_ovn_acls:
+                    add_rem_acls.append(add_acl)
+
+            # Remove any of the false-positive ACLs
+            LOG.warning('False-positive ACLs to remove: (%s)', add_rem_acls)
+            for add_rem in add_rem_acls:
+                add_acls.remove(add_rem)
+
         if n_index < neutron_num:
             # We didn't find the OVN ACLs matching the Neutron ACLs
             # in "ovn_acls" and we are just adding the pending Neutron ACLs.
@@ -837,7 +864,8 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                         LOG.warning("Add static routes %s to OVN NB DB",
                                     sroute['add'])
                         for route in sroute['add']:
-                            columns = {}
+                            columns = {'external_ids': {
+                                       ovn_const.OVN_LRSR_EXT_ID_KEY: 'true'}}
                             if 'external_ids' in route:
                                 columns['external_ids'] = route['external_ids']
                             txn.add(self.ovn_api.add_static_route(
@@ -853,11 +881,12 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                     if self.mode == SYNC_MODE_REPAIR:
                         LOG.warning("Delete static routes %s from OVN NB DB",
                                     sroute['del'])
-                        for route in sroute['del']:
-                            txn.add(self.ovn_api.delete_static_route(
-                                utils.ovn_name(sroute['id']),
-                                ip_prefix=route['destination'],
-                                nexthop=route['nexthop']))
+                        routes_to_delete = [
+                            (r['destination'], r['nexthop'])
+                            for r in sroute['del']
+                        ]
+                        txn.add(self.ovn_api.delete_static_routes(
+                            utils.ovn_name(sroute['id']), routes_to_delete))
             for fip in update_fips_list:
                 if fip['del']:
                     LOG.warning("Router %(id)s floating IPs %(fip)s "
